@@ -8,7 +8,7 @@ use HTTP::Request();
 use JSON::XS();
 use Encode qw(decode_utf8);
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use constant {
     ONE_REQ     => 1,
@@ -91,7 +91,8 @@ our %QS_Formatter = (
 sub new {
 #===================================
     my ( $proto, $params ) = &_params;
-    my $self = bless { _JSON => JSON::XS->new() }, ref $proto || $proto;
+    my $self = bless { _JSON => JSON::XS->new(), _base_qs => [], _camel_case=>0 },
+        ref $proto || $proto;
     my $servers = delete $params->{servers};
     for ( keys %$params ) {
         $self->$_( $params->{$_} );
@@ -538,6 +539,19 @@ sub nodes {
     );
 }
 
+#===================================
+sub nodes_stats {
+#===================================
+    shift()->_do_action(
+        'nodes',
+        {   prefix  => '_cluster/nodes',
+            postfix => 'stats',
+            cmd     => CMD_nodes,
+        },
+        @_
+    );
+}
+
 #===================================
 sub shutdown {
 #===================================
@@ -553,6 +567,21 @@ sub shutdown {
     );
 }
 
+#===================================
+sub restart {
+#===================================
+    shift()->_do_action(
+        'shutdown',
+        {   method  => 'POST',
+            prefix  => '_cluster/nodes',
+            cmd     => CMD_nodes,
+            postfix => '_restart',
+            qs      => { delay => [ 'duration', 'delay' ] }
+        },
+        @_
+    );
+}
+
 #===================================
 sub cluster_health {
 #===================================
@@ -573,6 +602,23 @@ sub cluster_health {
     );
 }
 
+#===================================
+sub camel_case {
+#===================================
+    my $self = shift;
+    if (@_) {
+        if ( shift() ) {
+            $self->{_camel_case} = 1;
+            $self->{_base_qs}    = ['case=camelCase'];
+        }
+        else {
+            $self->{_camel_case} = 0;
+            $self->{_base_qs}    = [];
+        }
+    }
+    return $self->{_camel_case};
+}
+
 #===================================
 sub _do_action {
 #===================================
@@ -661,7 +707,7 @@ sub _build_qs {
     my $self   = shift;
     my $params = shift;
     my $defn   = shift or return;
-    my @qs;
+    my @qs     = ( @{ $self->{_base_qs} } );
     foreach my $key ( keys %$defn ) {
         my ( $format_name, @args ) = @{ $defn->{$key} || [] };
         $format_name ||= '';
@@ -1101,7 +1147,7 @@ ElasticSearch - An API for communicating with ElasticSearch
 
 =head1 VERSION
 
-Version 0.12, tested against ElasticSearch server version 0.6.0.
+Version 0.13, tested against ElasticSearch server version 0.7.0.
 
 =cut
 
@@ -1163,17 +1209,17 @@ a randomly chosen node in the list.
 
 =head1 GETTING ElasticSearch
 
-To get the latest version from github, you can just install
-L<Alien::ElasticSearch>, or if you already have it installed, then try:
+You can download the latest released version of ElasticSearch from
+L<http://github.com/elasticsearch/elasticsearch/downloads>.
 
-    install_elasticsearch.pl --tag master
-
-Alternatively, you can download the latest release from
-L<http://www.elasticsearch.com/download/>, or to build from source on Unix:
+To build the latest development version from source, you can do
+the following:
 
     cd ~
-    git clone git://github.com/elasticsearch/elasticsearch.git
-    cd elasticsearch
+    rm -Rf elasticsearch*
+    wget http://github.com/elasticsearch/elasticsearch/tarball/master
+    tar -xzf elasticsearch*.gz
+    cd elasticsearch*
     ./gradlew
 
     cd /path/where/you/want/elasticsearch
@@ -1392,9 +1438,6 @@ against multiple indices and multiple types, eg:
         query   => { term => {user => 'kimchy' }}
     );
 
-Note: C<indices_boost> doesn't seem to have any effect in version 0.6.0
-of ElasticSearch.
-
 For all of the options that can be included in the C<query> parameter, see
 L<http://www.elasticsearch.com/docs/elasticsearch/rest_api/search> and
 L<http://www.elasticsearch.com/docs/elasticsearch/rest_api/query_dsl/>
@@ -1841,6 +1884,16 @@ C<settings> is C<true>, then it includes the node settings information.
 
 See: L<http://www.elasticsearch.com/docs/elasticsearch/rest_api/admin/cluster/nodes_info>
 
+=head3 C<nodes_stats()>
+
+    $result = $e->nodes_stats(
+        nodes       => multi,
+    );
+
+Returns various statistics about one or more nodes in the cluster.
+
+See: L<http://www.elasticsearch.com/docs/elasticsearch/rest_api/admin/cluster/nodes_stats/>
+
 =head3 C<shutdown()>
 
     $result = $e->shutdown(
@@ -1856,6 +1909,21 @@ C<node> can also have the values C<_local>, C<_master> or C<_all>.
 
 See: L<http://www.elasticsearch.com/docs/elasticsearch/rest_api/admin/cluster/nodes_shutdown/>
 
+=head3 C<restart()>
+
+    $result = $e->restart(
+        nodes       => multi,
+        delay       => '5s' | '10m'        # optional
+    );
+
+
+Restarts one or more nodes (or the whole cluster if no nodes specified),
+optionally with a delay.
+
+C<node> can also have the values C<_local>, C<_master> or C<_all>.
+
+See: L<http://www.elasticsearch.com/docs/elasticsearch/rest_api/admin/cluster/nodes_restart>
+
 =cut
 
 =head2 Module-specific methods
@@ -1936,6 +2004,16 @@ It is probably better not to fiddle with this!  ElasticSearch expects all
 data to be provided as Perl strings (not as UTF8 encoded byte strings) and
 returns all data from ElasticSearch as Perl strings.
 
+=head3 C<camel_case()>
+
+    $bool = $e->camel_case($bool)
+
+Gets/sets the camel_case flag. If true, then all JSON keys returned by
+ElasticSearch are in camelCase, instead of with_underscores.  This flag
+does not apply to the source document being indexed or fetched.
+
+Defaults to false.
+
 =cut
 
 =head3 C<request()>
@@ -2046,13 +2124,6 @@ JSON exception.
 
 Any documents indexed via this module will be not susceptible to this problem.
 
-=item L</"search()">
-
-The C<indices_boost> argument appears to have no effect in version 0.6.0 of
-ElasticSearch.
-
-See L<http://github.com/elasticsearch/elasticsearch/issues/issue/137>
-
 =item L</"scroll()">
 
 C<scroll()> is broken in version 0.6.0 of ElasticSearch.
